#
# spec file for package libfsapfs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

Name:           libfsapfs
%define lname   libfsapfs1
Version:        20240429
Release:        1.5
Summary:        Library and tools to access the Apple File System (APFS)
License:        LGPL-3.0-only
Group:          System/Filesystems
URL:            https://github.com/libyal/libfsapfs
Source:         https://github.com/libyal/libfsapfs/releases/download/%version/%name-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libfsapfs/releases/download/%version/%name-experimental-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcaes) >= 20240413
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfcache) >= 20240414
BuildRequires:  pkgconfig(libfdata) >= 20240415
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libfmos) >= 20240415
BuildRequires:  pkgconfig(libhmac) >= 20240417
BuildRequires:  pkgconfig(libuna) >= 20240414
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(zlib) >= 1.2.5
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libfsapfs is a library to access the Apple File System (APFS).

Read-only supported APFS formats:

* version 2

Supported APFS format features:

* ZLIB (DEFLATE) compression
* LZVN compression
* encryption

Unsupported APFS format features:

* APFS version 1
* Fusion drive (NX_INCOMPAT_FUSION)
* snapshots
* LZFSE compression, compression methods 11 and 12
* "uncompressed", compression methods 1, 9 and 10
* T2 encryption

%package devel
Summary:        Development files for libfsapfs
Group:          Development/Languages/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
Development files for %name.

%package tools
Summary:        Tools to access the Apple File System format
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
Tools to inspect Apple File System (APFS) images.

%package -n %lname
Summary:        Library for access to the Apple File System (APFS)
Group:          System/Libraries

%description -n %lname
%lname is a library for access to the Apple File System (APFS).

%prep
%autosetup -p1

%build
%define _lto_cflags -ffat-lto-objects
export LDFLAGS="-Wl,-z,relro,-z,now"
export CFLAGS="%optflags"
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static \
  --enable-wide-character-type \
  --enable-verbose-output \
  --enable-debug-output \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* "%buildroot/"
rm -fv "%buildroot/%_libdir"/*.la

%check
make check || /bin/true

%ldconfig_scriptlets -n %lname

%files -n %name
%license COPYING*
%_bindir/fsapfsinfo
%_bindir/fsapfsmount
%_mandir/man*/*

%files -n %name-devel
%_includedir/%{name}*
%_libdir/%{name}*.so
%_libdir/pkgconfig/*

%files -n %lname
%_libdir/%{name}*so.*

%files %python_files
%python_sitearch/pyfsapfs*

%changelog
* Mon Apr 29 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240429
  * No changelog was provided
* Sun Feb 18 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240218
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Wed Nov 22 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231122
  * Build system updates only
* Wed Nov 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231115
  * Recognize BTNODE_HASHED and BTNODE_NOHEADER
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Sun Jun 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230607
  * No changelog was provided
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Thu Nov  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221102
  * Moved LZVN compression to libfmos
  * More unspecified updates
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sat Jul  9 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220709
  * Updates to number of hard links support
  * Updates to device number support
* Sun May  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220501
  * Unspecific updates to format support
* Sat Apr 30 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220430
  * Unspecified updates to extended attributes, snapshot
    support and Python bindings
* Sat Jan 22 2022 Jan Engelhardt <jengelh@inai.de>
- Perform multipython builds.
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210513 (3def3dae)
  * No changelog was provided
- Add system-libs.patch
* Sun Feb 28 2021 Dirk Müller <dmueller@suse.com>
- update to 20201107:
  * no changelog available
* Wed Jan 15 2020 Matej Cepl <mcepl@suse.com>
- Initial effort to package libfsapf 20191221
